==> owncloud-10.0.7.tgz: owncloud/lib/l10n/zh_CN.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "无法写入“config”目录！",
    "This can usually be fixed by giving the webserver write access to the config directory" : "给 WEB 服务器 Config 目录设置写权限可以修复这个问题。",
    "See %s" : "查看 %s",
    "Sample configuration detected" : "示例配置检测",
    "PHP %s or higher is required." : "要求 PHP 版本 %s 或者更高。",
    "The command line tool %s could not be found" : "命令行工具 %s 未找到",
    "The library %s is not available." : "库文件 %s 不可用",
    "Unknown filetype" : "未知的文件类型",
    "Invalid image" : "无效的图像",
    "today" : "今天",
    "yesterday" : "昨天",
    "_%n day ago_::_%n days ago_" : ["%n 天前"],
    "last month" : "上月",
    "_%n month ago_::_%n months ago_" : ["%n 月前"],
    "last year" : "去年",
    "_%n year ago_::_%n years ago_" : ["%n 年前"],
    "_%n hour ago_::_%n hours ago_" : ["%n 小时前"],
    "_%n minute ago_::_%n minutes ago_" : ["%n 分钟前"],
    "seconds ago" : "秒前",
    "Builtin" : "内置",
    "None" : "不提醒",
    "Username and password" : "用户名和密码",
    "Username" : "用户名",
    "Password" : "密码",
    "Dot files are not allowed" : ".文件 不被允许",
    "File name is a reserved word" : "文件名包含敏感字符",
    "File name contains at least one invalid character" : "文件名中存在至少一个非法字符",
    "File name is too long" : "文件名过长",
    "App directory already exists" : "应用程序目录已存在",
    "Can't create app folder. Please fix permissions. %s" : "无法创建应用程序文件夹。请修正权限。%s",
    "No source specified when installing app" : "安装 App 时未指定来源",
    "No href specified when installing app from http" : "从 http 安装 App 时未指定链接",
    "No path specified when installing app from local file" : "从本地文件安装 App 时未指定路径",
    "Archives of type %s are not supported" : "不支持 %s 的压缩格式",
    "Failed to open archive when installing app" : "安装 App 是打开归档失败",
    "App does not provide an info.xml file" : "应用未提供 info.xml 文件",
    "App can't be installed because of not allowed code in the App" : "App 无法安装，因为 App 中有非法代码 ",
    "App can't be installed because it is not compatible with this version of ownCloud" : "App 无法安装，因为和当前 ownCloud 版本不兼容",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "App 无法安装，因为 App 包含不允许在非内置 App 中使用的 <shipped>true</shipped> 标签",
    "Apps" : "应用",
    "General" : "常规",
    "Storage" : "存储",
    "Security" : "安全",
    "Encryption" : "加密",
    "Sharing" : "共享",
    "Search" : "搜索",
    "Updates" : "更新",
    "%s enter the database username." : "%s 输入数据库用户名。",
    "%s enter the database name." : "%s 输入数据库名称。",
    "%s you may not use dots in the database name" : "%s 您不能在数据库名称中使用英文句号。",
    "Oracle connection could not be established" : "不能建立甲骨文连接",
    "Oracle username and/or password not valid" : "Oracle 数据库用户名和/或密码无效",
    "DB Error: \"%s\"" : "数据库错误：\"%s\"",
    "Offending command was: \"%s\"" : "冲突命令为：\"%s\"",
    "You need to enter either an existing account or the administrator." : "你需要输入一个数据库中已有的账户或管理员账户。",
    "Offending command was: \"%s\", name: %s, password: %s" : "冲突命令为：\"%s\"，名称：%s，密码：%s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL 数据库用户名和/或密码无效",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X 不被支持并且 %s 在这个平台上无法正常工作。请自行承担风险！",
    "For the best results, please consider using a GNU/Linux server instead." : "为了达到最好的效果，请考虑使用 GNU/Linux 服务器。",
    "Set an admin username." : "请设置一个管理员用户名。",
    "Set an admin password." : "请设置一个管理员密码。",
    "Invalid Federated Cloud ID" : "无效的联合云ID",
    "%s shared »%s« with you" : "%s 向您分享了 »%s«",
    "%s via %s" : "%s 通过 %s",
    "Sharing %s failed, because the file does not exist" : "共享 %s 失败，因为文件不存在。",
    "You are not allowed to share %s" : "您无权分享 %s",
    "Sharing %s failed, because the user %s does not exist" : "共享 %s 失败，因为用户 %s 不存在",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "共享 %s 失败，因为用户 %s 不是 %s 所属的任何组的用户",
    "Sharing %s failed, because this item is already shared with %s" : "共享 %s 失败，因为它已经共享给 %s",
    "Sharing %s failed, because the group %s does not exist" : "共享 %s 失败，因为 %s 组不存在",
    "Sharing %s failed, because %s is not a member of the group %s" : "共享 %s 失败，因为 %s 不是 %s 组的成员",
    "Sharing %s failed, because sharing with links is not allowed" : "共享 %s 失败，因为不允许用链接共享",
    "Not allowed to create a federated share with the same user" : "不能给你自己分享文件",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "文件：%s 分享失败，联合云无法找到 %s，请检查设置或联系管理员。",
    "Share type %s is not valid for %s" : "%s 不是 %s 的合法共享类型",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "设置 %s 权限失败，因为权限超出了 %s 已有权限。",
    "Setting permissions for %s failed, because the item was not found" : "设置 %s 的权限失败，因为未找到到对应项",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "共享后端 %s 必须实现 OCP\\Share_Backend 接口",
    "Sharing backend %s not found" : "未找到共享后端 %s",
    "Sharing backend for %s not found" : "%s 的共享后端未找到",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "共享 %s 失败，因为权限超过了 %s 已有权限",
    "Sharing %s failed, because resharing is not allowed" : "共享 %s 失败，因为不允许二次共享",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "共享 %s 失败，因为 %s 使用的共享后端未找到它的来源",
    "Sharing %s failed, because the file could not be found in the file cache" : "共享 %s 失败，因为未在文件缓存中找到文件。",
    "Could not find category \"%s\"" : "无法找到分类 \"%s\"",
    "A valid username must be provided" : "必须提供合法的用户名",
    "A valid password must be provided" : "必须提供合法的密码",
    "The username is already being used" : "用户名已被使用",
    "Help" : "帮助",
    "Settings" : "设置",
    "Users" : "用户",
    "web services under your control" : "您控制的网络服务",
    "File is currently busy, please try again later" : "文件当前正忙，请稍后再试",
    "Can't read file" : "无法读取文件",
    "Application is not enabled" : "应用程序未启用",
    "Authentication error" : "认证出错",
    "Token expired. Please reload page." : "Token 过期，请刷新页面。",
    "Unknown user" : "未知用户",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "没有安装数据库驱动 (SQLite、MySQL 或 PostgreSQL)。",
    "Cannot write into \"config\" directory" : "无法写入“config”目录",
    "Cannot write into \"apps\" directory" : "无法写入“apps”目录",
    "Setting locale to %s failed" : "设置语言为 %s 失败",
    "Please ask your server administrator to install the module." : "请联系服务器管理员安装模块。",
    "PHP module %s not installed." : "PHP %s 模块未安装。",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP 设定 \"%s\" 未设置为 \"%s\"。",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "这可能是由缓存/加速器造成的，例如 Zend OPcache 或 eAccelerator。",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP 模块已经安装，但仍然显示未安装？",
    "Please ask your server administrator to restart the web server." : "请联系服务器管理员重启网页服务器。",
    "PostgreSQL >= 9 required" : "要求 PostgreSQL >= 9",
    "Please upgrade your database version" : "请升级您的数据库版本",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "请更改权限为 0770 以避免其他用户查看目录。",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "请确保文件根目录下包含有一个名为“.ocdata”的文件。",
    "Storage is temporarily not available" : "存储临时性不可用"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.10.tgz: owncloud/lib/l10n/zh_CN.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "无法写入“config”目录！",
    "This can usually be fixed by giving the webserver write access to the config directory" : "给 WEB 服务器 Config 目录设置写权限可以修复这个问题。",
    "See %s" : "查看 %s",
    "Sample configuration detected" : "示例配置检测",
    "PHP %s or higher is required." : "要求 PHP 版本 %s 或者更高。",
    "The command line tool %s could not be found" : "命令行工具 %s 未找到",
    "The library %s is not available." : "库文件 %s 不可用",
    "Unknown filetype" : "未知的文件类型",
    "Invalid image" : "无效的图像",
    "today" : "今天",
    "yesterday" : "昨天",
    "_%n day ago_::_%n days ago_" : ["%n 天前"],
    "last month" : "上月",
    "_%n month ago_::_%n months ago_" : ["%n 月前"],
    "last year" : "去年",
    "_%n year ago_::_%n years ago_" : ["%n 年前"],
    "_%n hour ago_::_%n hours ago_" : ["%n 小时前"],
    "_%n minute ago_::_%n minutes ago_" : ["%n 分钟前"],
    "seconds ago" : "秒前",
    "Builtin" : "内置",
    "None" : "不提醒",
    "Username and password" : "用户名和密码",
    "Username" : "用户名",
    "Password" : "密码",
    "Dot files are not allowed" : ".文件 不被允许",
    "File name is a reserved word" : "文件名包含敏感字符",
    "File name contains at least one invalid character" : "文件名中存在至少一个非法字符",
    "File name is too long" : "文件名过长",
    "App directory already exists" : "应用程序目录已存在",
    "Can't create app folder. Please fix permissions. %s" : "无法创建应用程序文件夹。请修正权限。%s",
    "No source specified when installing app" : "安装 App 时未指定来源",
    "No href specified when installing app from http" : "从 http 安装 App 时未指定链接",
    "No path specified when installing app from local file" : "从本地文件安装 App 时未指定路径",
    "Archives of type %s are not supported" : "不支持 %s 的压缩格式",
    "Failed to open archive when installing app" : "安装 App 是打开归档失败",
    "App does not provide an info.xml file" : "应用未提供 info.xml 文件",
    "App can't be installed because of not allowed code in the App" : "App 无法安装，因为 App 中有非法代码 ",
    "App can't be installed because it is not compatible with this version of ownCloud" : "App 无法安装，因为和当前 ownCloud 版本不兼容",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "App 无法安装，因为 App 包含不允许在非内置 App 中使用的 <shipped>true</shipped> 标签",
    "Apps" : "应用",
    "General" : "常规",
    "Storage" : "存储",
    "Security" : "安全",
    "Encryption" : "加密",
    "Sharing" : "共享",
    "Search" : "搜索",
    "Updates" : "更新",
    "%s enter the database username." : "%s 输入数据库用户名。",
    "%s enter the database name." : "%s 输入数据库名称。",
    "%s you may not use dots in the database name" : "%s 您不能在数据库名称中使用英文句号。",
    "Oracle connection could not be established" : "不能建立甲骨文连接",
    "Oracle username and/or password not valid" : "Oracle 数据库用户名和/或密码无效",
    "DB Error: \"%s\"" : "数据库错误：\"%s\"",
    "Offending command was: \"%s\"" : "冲突命令为：\"%s\"",
    "You need to enter either an existing account or the administrator." : "你需要输入一个数据库中已有的账户或管理员账户。",
    "Offending command was: \"%s\", name: %s, password: %s" : "冲突命令为：\"%s\"，名称：%s，密码：%s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL 数据库用户名和/或密码无效",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X 不被支持并且 %s 在这个平台上无法正常工作。请自行承担风险！",
    "For the best results, please consider using a GNU/Linux server instead." : "为了达到最好的效果，请考虑使用 GNU/Linux 服务器。",
    "Set an admin username." : "请设置一个管理员用户名。",
    "Set an admin password." : "请设置一个管理员密码。",
    "Invalid Federated Cloud ID" : "无效的联合云ID",
    "%s shared »%s« with you" : "%s 向您分享了 »%s«",
    "%s via %s" : "%s 通过 %s",
    "Sharing %s failed, because the file does not exist" : "共享 %s 失败，因为文件不存在。",
    "You are not allowed to share %s" : "您无权分享 %s",
    "Sharing %s failed, because the user %s does not exist" : "共享 %s 失败，因为用户 %s 不存在",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "共享 %s 失败，因为用户 %s 不是 %s 所属的任何组的用户",
    "Sharing %s failed, because this item is already shared with %s" : "共享 %s 失败，因为它已经共享给 %s",
    "Sharing %s failed, because the group %s does not exist" : "共享 %s 失败，因为 %s 组不存在",
    "Sharing %s failed, because %s is not a member of the group %s" : "共享 %s 失败，因为 %s 不是 %s 组的成员",
    "Sharing %s failed, because sharing with links is not allowed" : "共享 %s 失败，因为不允许用链接共享",
    "Not allowed to create a federated share with the same user" : "不能给你自己分享文件",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "文件：%s 分享失败，联合云无法找到 %s，请检查设置或联系管理员。",
    "Share type %s is not valid for %s" : "%s 不是 %s 的合法共享类型",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "设置 %s 权限失败，因为权限超出了 %s 已有权限。",
    "Setting permissions for %s failed, because the item was not found" : "设置 %s 的权限失败，因为未找到到对应项",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "共享后端 %s 必须实现 OCP\\Share_Backend 接口",
    "Sharing backend %s not found" : "未找到共享后端 %s",
    "Sharing backend for %s not found" : "%s 的共享后端未找到",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "共享 %s 失败，因为权限超过了 %s 已有权限",
    "Sharing %s failed, because resharing is not allowed" : "共享 %s 失败，因为不允许二次共享",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "共享 %s 失败，因为 %s 使用的共享后端未找到它的来源",
    "Sharing %s failed, because the file could not be found in the file cache" : "共享 %s 失败，因为未在文件缓存中找到文件。",
    "Could not find category \"%s\"" : "无法找到分类 \"%s\"",
    "A valid username must be provided" : "必须提供合法的用户名",
    "A valid password must be provided" : "必须提供合法的密码",
    "The username is already being used" : "用户名已被使用",
    "Help" : "帮助",
    "Settings" : "设置",
    "Users" : "用户",
    "web services under your control" : "您控制的网络服务",
    "File is currently busy, please try again later" : "文件当前正忙，请稍后再试",
    "Can't read file" : "无法读取文件",
    "Application is not enabled" : "应用程序未启用",
    "Authentication error" : "认证出错",
    "Token expired. Please reload page." : "Token 过期，请刷新页面。",
    "Unknown user" : "未知用户",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "没有安装数据库驱动 (SQLite、MySQL 或 PostgreSQL)。",
    "Cannot write into \"config\" directory" : "无法写入“config”目录",
    "Cannot write into \"apps\" directory" : "无法写入“apps”目录",
    "Setting locale to %s failed" : "设置语言为 %s 失败",
    "Please ask your server administrator to install the module." : "请联系服务器管理员安装模块。",
    "PHP module %s not installed." : "PHP %s 模块未安装。",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP 设定 \"%s\" 未设置为 \"%s\"。",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "这可能是由缓存/加速器造成的，例如 Zend OPcache 或 eAccelerator。",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP 模块已经安装，但仍然显示未安装？",
    "Please ask your server administrator to restart the web server." : "请联系服务器管理员重启网页服务器。",
    "PostgreSQL >= 9 required" : "要求 PostgreSQL >= 9",
    "Please upgrade your database version" : "请升级您的数据库版本",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "请更改权限为 0770 以避免其他用户查看目录。",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "请确保文件根目录下包含有一个名为“.ocdata”的文件。",
    "Storage is temporarily not available" : "存储临时性不可用",
    "Help & Tips" : "帮助",
    "A safe home for all your data" : "为您的所有数据提供一个安全的家。",
    "User Authentication" : "用户授权",
    "Storage connection timeout. %s" : "存储连接超时。%s",
    "Avatar image is not square" : "Avatar 头像图片非方形",
    "Empty filename is not allowed" : "不允许使用空文件名",
    "PHP with a version lower than %s is required." : "要求 PHP 的版本低于 %s。",
    "To fix this issue update your libxml2 version and restart your web server." : "修复这个问题需要更新 libxml2 的版本并重启您的网页服务器。",
    "Imprint" : "版本说明",
    "__language_name__" : "简体中文",
    "Privacy Policy" : "隐私政策"
},
"nplurals=1; plural=0;");
